# Your Clients/Prospects/Contacts
A list of entries for which you are the approved relationship manager.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The client's name.

### Primary Telephone:
The client's primary telephone number.

### Primary Email:
The primary email address for the client.

### Primary Address:
The client's primary address.

## Buttons:
Each row can be right-clicked to reveal a button labeled "See entry" which will redirect you to the entry instance.

## Filters:

### No Activity:
Filter clients with no activity for x amount of time.

## Search Field:
Typing in the search field allows to filter the clients by name.
